pub struct ShaderParams { /* private fields */ }Expand description
Parameters to be passed to a process shader.
Each call to a set_param_ function will push a parameter of that
type to the arguments list, so calls should be made in the order in which
parameters are required to be sent to the shader.
Implementations
Sourceimpl ShaderParams
impl ShaderParams
pub fn set_param_video_frame_input(&mut self, video_frame: VideoFrame)
pub fn set_param_u32_input(&mut self, val: u32)
pub fn set_param_f32_input(&mut self, val: f32)
Sourcepub fn set_param_video_frame_output(&mut self, width: usize, height: usize)
pub fn set_param_video_frame_output(&mut self, width: usize, height: usize)
Sets a video frame as an output of a shader.
pub fn get_params(&self) -> &RVec<ShaderParam>