AudioOutput

Trait AudioOutput 

pub trait AudioOutput: Send + Sync {
    // Required method
    fn push_frame(&self, context: &FrameContext, frame: AudioFrame);
}
An audio output from a node, this is where the audio frames a node creates shoud be sent to be forwarded to other nodes.

Required Methods

fn push_frame(&self, context: &FrameContext, frame: AudioFrame)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'lt, _ErasedPtr> AudioOutput for AudioOutput_TO<'lt, _ErasedPtr>
where Self: Send + Sync, _ErasedPtr: AsPtr<PtrTarget = ()>,