ConsumedVideoFrame

Trait ConsumedVideoFrame 

pub trait ConsumedVideoFrame { }
A handle to a video frame that has been transformed into a requested colour space. This handle is used to request a copy of the frame.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'lt, _ErasedPtr> ConsumedVideoFrame for ConsumedVideoFrame_TO<'lt, _ErasedPtr>
where Self:, _ErasedPtr: AsPtr<PtrTarget = ()>,