pub trait FrameContext { }Expand description
Provides proof that frame copy operations can be performed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait FrameContext { }Provides proof that frame copy operations can be performed.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".