This module is generated by the #[sabi_trait] attribute on LoadedVideoFrame
Structs
- Loaded
Video Frame_ Interface - A marker type describing the traits that are required when constructing
LoadedVideoFrame_TO,and are then implemented by it, by implementing theInterfaceTypetrait. - Loaded
Video Frame_ TO - The trait object for LoadedVideoFrame.
Traits
- Loaded
Video Frame - A handle to a video frame that has been loaded onto the GPU but not yet converted.
Type Aliases
- Loaded
Video Frame_ Backend - An alias for the underlying implementation of
LoadedVideoFrame_TO. - Loaded
Video Frame_ CTO - A type alias for the const-constructible
LoadedVideoFrame_TO.