pub trait NodeHandle: Send + Sync {
// Required method
fn initialize(
&self,
context: NodeContext,
configuration: ROption<RString>,
) -> Node;
}Expand description
A handle to a node that can be initialized later. Serves as a reservation of the node and associated resources.
Required Methods
fn initialize( &self, context: NodeContext, configuration: ROption<RString>, ) -> Node
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".