Module ProcessFrameContext_trait

Module ProcessFrameContext_trait 

This module is generated by the #[sabi_trait] attribute on ProcessFrameContext

Structs

ProcessFrameContext_Interface
A marker type describing the traits that are required when constructing ProcessFrameContext_TO,and are then implemented by it, by implementing the InterfaceType trait.
ProcessFrameContext_TO
The trait object for ProcessFrameContext.

Traits

ProcessFrameContext
Provides proof that frame processing operations can be performed. Must be submitted to acquire a FrameContext that can be used for copy operations. This proves that all of the processing operations for a node have been submitted before the frame attempts to consume a frame.

Type Aliases

ProcessFrameContext_Backend
An alias for the underlying implementation of ProcessFrameContext_TO.
ProcessFrameContext_CTO
A type alias for the const-constructible ProcessFrameContext_TO.