pub trait ProcessShader: Send + Sync {
// Required method
fn run(
&self,
params: ShaderParams,
global_work_size: &[usize; 2],
) -> RVec<VideoFrame> ⓘ;
}Expand description
Once a process shader has been created, this trait allows a node to interact with the shader.
Required Methods
fn run( &self, params: ShaderParams, global_work_size: &[usize; 2], ) -> RVec<VideoFrame> ⓘ
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".