VideoOutput

Trait VideoOutput 

pub trait VideoOutput: Send + Sync {
    // Required method
    fn push_frame(&self, context: &FrameContext, frame: VideoFrame);
}
A video output from a node, this is where the video frames a node creates should be sent to be forwarded to other nodes.

Required Methods

fn push_frame(&self, context: &FrameContext, frame: VideoFrame)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'lt, _ErasedPtr> VideoOutput for VideoOutput_TO<'lt, _ErasedPtr>
where Self: Send + Sync, _ErasedPtr: AsPtr<PtrTarget = ()>,