NodeHandle

Trait NodeHandle 

pub trait NodeHandle: Send + Sync {
    // Required method
    fn initialize(
        &self,
        context: NodeContext,
        configuration: ROption<RString>,
    ) -> Node;
}
A handle to a node that can be initialized later. Serves as a reservation of the node and associated resources.

Required Methods

fn initialize( &self, context: NodeContext, configuration: ROption<RString>, ) -> Node

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'lt, _ErasedPtr> NodeHandle for NodeHandle_TO<'lt, _ErasedPtr>
where Self: Send + Sync, _ErasedPtr: AsPtr<PtrTarget = ()>,