ToAudioF32

Trait ToAudioF32 

pub trait ToAudioF32: Send + Sync {
    // Required methods
    fn load_frame(&self, input: &RSlice<'_, u8>) -> LoadedAudioFrame;
    fn process_frame(&self, source: LoadedAudioFrame) -> AudioFrame;
}
Provides functions for creating audio frames in 32 bit floating point format.

Required Methods

fn load_frame(&self, input: &RSlice<'_, u8>) -> LoadedAudioFrame

Copies the input but does not transform it into the required format.

fn process_frame(&self, source: LoadedAudioFrame) -> AudioFrame

Transforms a loaded audio frame into the common audio format.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'lt, _ErasedPtr> ToAudioF32 for ToAudioF32_TO<'lt, _ErasedPtr>
where Self: Send + Sync, _ErasedPtr: AsPtr<PtrTarget = ()>,