Module LoadedVideoFrame_trait

Module LoadedVideoFrame_trait 

This module is generated by the #[sabi_trait] attribute on LoadedVideoFrame

Structs

LoadedVideoFrame_Interface
A marker type describing the traits that are required when constructing LoadedVideoFrame_TO,and are then implemented by it, by implementing the InterfaceType trait.
LoadedVideoFrame_TO
The trait object for LoadedVideoFrame.

Traits

LoadedVideoFrame
A handle to a video frame that has been loaded onto the GPU but not yet converted.

Type Aliases

LoadedVideoFrame_Backend
An alias for the underlying implementation of LoadedVideoFrame_TO.
LoadedVideoFrame_CTO
A type alias for the const-constructible LoadedVideoFrame_TO.