This module is generated by the #[sabi_trait] attribute on ProcessFrameContext
Structs
- Process
Frame Context_ Interface - A marker type describing the traits that are required when constructing
ProcessFrameContext_TO,and are then implemented by it, by implementing theInterfaceTypetrait. - Process
Frame Context_ TO - The trait object for ProcessFrameContext.
Traits
- Process
Frame Context - Provides proof that frame processing operations can be performed.
Must be submitted to acquire a
FrameContextthat can be used for copy operations. This proves that all of the processing operations for a node have been submitted before the frame attempts to consume a frame.
Type Aliases
- Process
Frame Context_ Backend - An alias for the underlying implementation of
ProcessFrameContext_TO. - Process
Frame Context_ CTO - A type alias for the const-constructible
ProcessFrameContext_TO.