pub trait VideoOutput: Send + Sync {
// Required method
fn push_frame(&self, context: &FrameContext, frame: VideoFrame);
}Expand description
A video output from a node, this is where the video frames a node creates should be sent to be forwarded to other nodes.
Required Methods
fn push_frame(&self, context: &FrameContext, frame: VideoFrame)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".